@@ -1,7 +1,7 @@
 import os
 
 import pytest
-import requests_mock
+from pytest_httpx import HTTPXMock
 
 from lago_python_client.client import Client
 from lago_python_client.exceptions import LagoApiError
@@ -14,6 +14,7 @@ def plan_object():
         charge_model='standard',
         amount_currency='EUR',
         instant=True,
+        min_amount_cents=0,
         group_properties = [
             {
                 'group_id': 'id',
@@ -77,7 +78,7 @@ def mock_response():
     this_dir = os.path.dirname(os.path.abspath(__file__))
     data_path = os.path.join(this_dir, 'fixtures/plan.json')
 
-    with open(data_path, 'r') as plan_response:
+    with open(data_path, 'rb') as plan_response:
         return plan_response.read()
 
 
@@ -85,7 +86,7 @@ def mock_graduated_response():
     this_dir = os.path.dirname(os.path.abspath(__file__))
     data_path = os.path.join(this_dir, 'fixtures/graduated_plan.json')
 
-    with open(data_path, 'r') as plan_response:
+    with open(data_path, 'rb') as plan_response:
         return plan_response.read()
 
 
@@ -93,144 +94,128 @@ def mock_collection_response():
     this_dir = os.path.dirname(os.path.abspath(__file__))
     data_path = os.path.join(this_dir, 'fixtures/plan_index.json')
 
-    with open(data_path, 'r') as plan_response:
+    with open(data_path, 'rb') as plan_response:
         return plan_response.read()
 
 
-def test_valid_create_plan_request():
+def test_valid_create_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('POST', 'https://api.getlago.com/api/v1/plans', text=mock_response())
-        response = client.plans().create(plan_object())
+    httpx_mock.add_response(method='POST', url='https://api.getlago.com/api/v1/plans', content=mock_response())
+    response = client.plans.create(plan_object())
 
     assert response.lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac129b'
     assert response.code == 'plan_code'
 
 
-def test_valid_create_graduated_plan_request():
+def test_valid_create_graduated_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('POST', 'https://api.getlago.com/api/v1/plans', text=mock_graduated_response())
-        response = client.plans().create(graduated_plan_object())
+    httpx_mock.add_response(method='POST', url='https://api.getlago.com/api/v1/plans', content=mock_graduated_response())
+    response = client.plans.create(graduated_plan_object())
 
     assert response.lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac129b'
     assert response.code == 'plan_code'
 
 
-def test_invalid_create_plan_request():
+def test_invalid_create_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='invalid')
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('POST', 'https://api.getlago.com/api/v1/plans', status_code=401, text='')
+    httpx_mock.add_response(method='POST', url='https://api.getlago.com/api/v1/plans', status_code=401, content=b'')
 
-        with pytest.raises(LagoApiError):
-            client.plans().create(plan_object())
+    with pytest.raises(LagoApiError):
+        client.plans.create(plan_object())
 
 
-def test_valid_update_plan_request():
+def test_valid_update_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
     code = 'plan_code'
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('PUT',
-                       'https://api.getlago.com/api/v1/plans/' + code,
-                       text=mock_response())
-        response = client.plans().update(plan_object(), code)
+    httpx_mock.add_response(method='PUT', url='https://api.getlago.com/api/v1/plans/' + code, content=mock_response())
+    response = client.plans.update(plan_object(), code)
 
     assert response.lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac129b'
     assert response.code == code
 
 
-def test_invalid_update_plan_request():
+def test_invalid_update_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='invalid')
     code = 'invalid'
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('PUT',
-                       'https://api.getlago.com/api/v1/plans/' + code,
-                       status_code=401,
-                       text='')
+    httpx_mock.add_response(method='PUT', url='https://api.getlago.com/api/v1/plans/' + code, status_code=401, content=b'')
 
-        with pytest.raises(LagoApiError):
-            client.plans().update(plan_object(), code)
+    with pytest.raises(LagoApiError):
+        client.plans.update(plan_object(), code)
 
 
-def test_valid_find_plan_request():
+def test_valid_find_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
     code = 'plan_code'
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('GET', 'https://api.getlago.com/api/v1/plans/' + code, text=mock_response())
-        response = client.plans().find(code)
+    httpx_mock.add_response(method='GET', url='https://api.getlago.com/api/v1/plans/' + code, content=mock_response())
+    response = client.plans.find(code)
 
     assert response.lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac129b'
     assert response.code == code
     assert response.charges.__root__[0].charge_model == 'standard'
+    assert response.charges.__root__[0].min_amount_cents == 0
 
 
-def test_invalid_find_plan_request():
+def test_invalid_find_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='invalid')
     code = 'invalid'
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('GET', 'https://api.getlago.com/api/v1/plans/' + code, status_code=404, text='')
+    httpx_mock.add_response(method='GET', url='https://api.getlago.com/api/v1/plans/' + code, status_code=404, content=b'')
 
-        with pytest.raises(LagoApiError):
-            client.plans().find(code)
+    with pytest.raises(LagoApiError):
+        client.plans.find(code)
 
 
-def test_valid_destroy_plan_request():
+def test_valid_destroy_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
     code = 'plan_code'
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('DELETE', 'https://api.getlago.com/api/v1/plans/' + code, text=mock_response())
-        response = client.plans().destroy(code)
+    httpx_mock.add_response(method='DELETE', url='https://api.getlago.com/api/v1/plans/' + code, content=mock_response())
+    response = client.plans.destroy(code)
 
     assert response.lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac129b'
     assert response.code == code
 
 
-def test_invalid_destroy_plan_request():
+def test_invalid_destroy_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='invalid')
     code = 'invalid'
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('DELETE', 'https://api.getlago.com/api/v1/plans/' + code, status_code=404, text='')
+    httpx_mock.add_response(method='DELETE', url='https://api.getlago.com/api/v1/plans/' + code, status_code=404, content=b'')
 
-        with pytest.raises(LagoApiError):
-            client.plans().destroy(code)
+    with pytest.raises(LagoApiError):
+        client.plans.destroy(code)
 
 
-def test_valid_find_all_plan_request():
+def test_valid_find_all_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('GET', 'https://api.getlago.com/api/v1/plans', text=mock_collection_response())
-        response = client.plans().find_all()
+    httpx_mock.add_response(method='GET', url='https://api.getlago.com/api/v1/plans', content=mock_collection_response())
+    response = client.plans.find_all()
 
     assert response['plans'][0].lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac1111'
     assert response['meta']['current_page'] == 1
 
 
-def test_valid_find_all_plan_request_with_options():
+def test_valid_find_all_plan_request_with_options(httpx_mock: HTTPXMock):
     client = Client(api_key='886fe239-927d-4072-ab72-6dd345e8dd0d')
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('GET', 'https://api.getlago.com/api/v1/plans?per_page=2&page=1', text=mock_collection_response())
-        response = client.plans().find_all({'per_page': 2, 'page': 1})
+    httpx_mock.add_response(method='GET', url='https://api.getlago.com/api/v1/plans?per_page=2&page=1', content=mock_collection_response())
+    response = client.plans.find_all({'per_page': 2, 'page': 1})
 
     assert response['plans'][1].lago_id == 'b7ab2926-1de8-4428-9bcd-779314ac1222'
     assert response['meta']['current_page'] == 1
 
 
-def test_invalid_find_all_plan_request():
+def test_invalid_find_all_plan_request(httpx_mock: HTTPXMock):
     client = Client(api_key='invalid')
 
-    with requests_mock.Mocker() as m:
-        m.register_uri('GET', 'https://api.getlago.com/api/v1/plans', status_code=404, text='')
+    httpx_mock.add_response(method='GET', url='https://api.getlago.com/api/v1/plans', status_code=404, content=b'')
 
-        with pytest.raises(LagoApiError):
-            client.plans().find_all()
+    with pytest.raises(LagoApiError):
+        client.plans.find_all()
